pub struct HelloService;Trait Implementations
Sourceimpl Default for HelloService
impl Default for HelloService
Sourcefn default() -> HelloService
fn default() -> HelloService
Returns the “default value” for a type. Read more
Sourceimpl GrpcServiceHandler for HelloService
impl GrpcServiceHandler for HelloService
Sourcefn service_name(&self) -> &'static str
fn service_name(&self) -> &'static str
The name of the service for logging and identification purposes
Sourcefn file_descriptor_set(&self) -> &'static [u8] ⓘ
fn file_descriptor_set(&self) -> &'static [u8] ⓘ
The compiled protobuf file descriptor set used for gRPC reflection
This should be generated using prost-build and included at compile time
Sourcefn register_service(self: &Arc<Self>, builder: &mut RoutesBuilder)
fn register_service(self: &Arc<Self>, builder: &mut RoutesBuilder)
Register the service implementation with the tonic routes builder
This method should wrap the service in the appropriate tonic-generated
server and add it to the builder
Sourcefn readiness_reporting<'life0, 'async_trait>(
self: &'life0 Arc<Self>,
_cancellation_token: CancellationToken,
reporter: HealthReporter,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn readiness_reporting<'life0, 'async_trait>(
self: &'life0 Arc<Self>,
_cancellation_token: CancellationToken,
reporter: HealthReporter,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
readiness_reporting is called after the service is registered and
allows the service to set its initial health statusSourceimpl HelloService for HelloService
impl HelloService for HelloService