Module http

Module http 

Structs

RestServerConfig
Configuration options for a REST server
RestServerConfigBuilder
Use builder syntax to set the inputs and finish with build().

Constants

DEFAULT_MAX_HTTP_BODY_SIZE
Default maximum HTTP request body size (100 MB)

Functions

health_routes
Add health routes to the router
start_rest_server
Starts the REST server and returns a handle for managing its lifecycle.