Structs
- Rest
Server Config - Configuration options for a REST server
- Rest
Server Config Builder - Use builder syntax to set the inputs and finish with
build().
Constants
- DEFAULT_
MAX_ HTTP_ BODY_ SIZE - Default maximum HTTP request body size (100 MB)
Functions
- health_
routes - Add health routes to the router
- start_
rest_ server - Starts the REST server and returns a handle for managing its lifecycle.